CurvePoint class
A single control point on a HapticCurve.
- Annotations
-
- @immutable
Constructors
- CurvePoint(Duration time, double value)
-
Creates a control point at
time(relative to the start of the pattern) with the givenvalue.const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- time → Duration
-
When this point takes effect, relative to the start of the pattern.
final
- value → double
-
The parameter value at time. Values between points are interpolated
linearly.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override